import javax.media.j3d.* ;
import javax.vecmath.* ;
import com.sun.j3d.utils.image.TextureLoader;

/**
 * Classe correspondant au sol de l'application
 * Le role de cette classe est de creer le sous graphe de scene
 * representant un sol.
 */
class Sol
{
    /**
     * Sommet du sous graphe de scene representant un sol
     */
    protected BranchGroup sol ;

    /** 
     * Largeur du sol
     */
    protected final float largeur = 20 ;

    protected final Point3f p1 = new Point3f(-largeur/2.0f,-largeur/2.0f,0.0f);
    protected final Point3f p2 = new Point3f(largeur/2.0f,-largeur/2.0f,0.0f) ;
    protected final Point3f p3 = new Point3f(largeur/2.0f,largeur/2.0f,0.0f) ;
    protected final Point3f p4 = new Point3f(-largeur/2.0f,largeur/2.0f,0.0f) ;

    /**
     * Description de la face representant le sol
     */
    protected final Point3f[] verts = {p1,p2,p3,p4} ;

    /**
     * Coordonnees texture sur le sol
     */
    protected final TexCoord2f texCoord[] = {
	new TexCoord2f(0.0f,0.0f),
	new TexCoord2f(10.0f,0.0f),
	new TexCoord2f(10.0f,10.0f),
	new TexCoord2f(0.0f,10.0f)} ;
	

    /**
     * Constructeur du sol. 
     * Son role est de construire le sous graphe de scene
     */
    public Sol()
    {
	QuadArray geom = new QuadArray(4, QuadArray.COORDINATES |
				       QuadArray.TEXTURE_COORDINATE_2) ;
	sol = new BranchGroup() ;
	Shape3D face = new Shape3D(geom) ;
	sol.addChild(face) ;
	geom.setCoordinates(0,verts) ;
	for (int i=0; i<4; i++)
	    geom.setTextureCoordinate(0,i,texCoord[i]) ;

	// creation de l'apparence du sol 
	Appearance app = new Appearance() ;

	// chargement de la texture
	TextureLoader tex = new TextureLoader("sol.jpg", Appli.mainFrame);
	app.setTexture(tex.getTexture());

	Color3f black = new Color3f(0.0f, 0.0f, 0.0f);
	Color3f white = new Color3f(1.0f, 1.0f, 1.0f);
	// on fixe les proprietes du materiau
	app.setMaterial(new Material(white, black, white, black, 1.0f));
	
	face.setAppearance(app) ;
    }

    /** 
     * methode renvoyant le sous graphe de scene associe
     * @return le sous graphe de scene
     */
    public Node getSol()
    {
	return sol ;
    }
}

